@@ -11,27 +11,34 @@ from typing import Any, Dict, List
 
 import numpy as np
 
+from sinethesizer.effects.amplitude import (
+    apply_amplitude_normalization, apply_compressor, apply_envelope_shaper
+)
+from sinethesizer.effects.chorus import apply_chorus
 from sinethesizer.effects.equalizer import apply_equalizer
 from sinethesizer.effects.filter import apply_frequency_filter
 from sinethesizer.effects.filter_sweep import apply_filter_sweep, apply_phaser
 from sinethesizer.effects.overdrive import apply_overdrive
-from sinethesizer.effects.reverb import apply_reverb
-from sinethesizer.effects.stereo import apply_haas_effect, apply_panning
+from sinethesizer.effects.reverb import apply_artificial_reverb, apply_room_reverb
+from sinethesizer.effects.stereo import apply_panning, apply_stereo_delay
 from sinethesizer.effects.tremolo import apply_tremolo
 from sinethesizer.effects.vibrato import apply_vibrato
-from sinethesizer.effects.volume import apply_amplitude_normalization
 
 
 REGISTRY_OF_AUTOMATABLE_EFFECTS = {
     'amplitude_normalization': apply_amplitude_normalization,
+    'artificial_reverb': apply_artificial_reverb,
+    'chorus': apply_chorus,
+    'compressor': apply_compressor,
+    'envelope_shaper': apply_envelope_shaper,
     'equalizer': apply_equalizer,
     'filter': apply_frequency_filter,
     'filter_sweep': apply_filter_sweep,
-    'haas': apply_haas_effect,
     'overdrive': apply_overdrive,
     'panning': apply_panning,
     'phaser': apply_phaser,
-    'reverb': apply_reverb,
+    'room_reverb': apply_room_reverb,
+    'stereo_delay': apply_stereo_delay,
     'tremolo': apply_tremolo,
     'vibrato': apply_vibrato,
 }
