@@ -5,21 +5,19 @@ Author: Nikolay Lysenko
 """
 
 
-from typing import Any, Dict
-
 import numpy as np
 
 
 def apply_overdrive(
-        sound: np.ndarray, sound_info: Dict[str, Any],
-        fraction_to_clip: float = 0.1, strength: float = 0.3
+        sound: np.ndarray, event: 'sinethesizer.synth.core.Event',
+        fraction_to_clip: float = 0.1, strength: float = 0.333
 ) -> np.ndarray:
     """
     Overdrive the sound.
 
     :param sound:
         sound to be modified
-    :param sound_info:
+    :param event:
         an argument that is not used by this function;
         it is added, because all effect functions must have it
     :param fraction_to_clip:
@@ -33,7 +31,7 @@ def apply_overdrive(
         raise ValueError("Fraction to clip must be between 0 and 1.")
     if not (0 <= strength < 1):
         raise ValueError("Overdrive strength must be between 0 and 1.")
-    _ = sound_info  # This argument is ignored.
+    _ = event  # This argument is ignored.
 
     abs_sound = np.abs(sound)
     clipping_threshold = np.quantile(abs_sound, 1 - fraction_to_clip, axis=1)
