@@ -74,16 +74,18 @@ def create_exponentially_decaying_envelope(
     :param peak_value:
         peak envelope value given maximum velocity; usually, this argument
         should be passed only if output envelope is used as modulation index envelope
+        or if the function is called by envelope shaper
     :param ratio_at_zero_velocity:
         ratio of envelope values at zero velocity to envelope values at maximum
         velocity; usually, this argument should be passed only if output
-        envelope is used as modulation index envelope
+        envelope is used as modulation index envelope or if the function is called by
+        envelope shaper
     :param envelope_values_on_velocity_order:
         coefficient that determines dependence of envelope values on velocity;
         given non-maximum positive velocity, the higher it is, the lower
         envelope values are; if it is 0, velocity does not affect envelope;
         usually, this argument should be passed only if output envelope is
-        used as modulation index envelope
+        used as modulation index envelope or if the function is called by envelope shaper
     :return:
         envelope
     """
