@@ -5,11 +5,18 @@ Author: Nikolay Lysenko
 """
 
 
-from tempfile import NamedTemporaryFile
+from tempfile import NamedTemporaryFile, TemporaryDirectory
 
 import pytest
 
 
+@pytest.fixture()
+def path_to_tmp_dir() -> str:
+    """Get path to empty temporary directory."""
+    with TemporaryDirectory() as path_to_tmp_dir:
+        yield path_to_tmp_dir
+
+
 @pytest.fixture()
 def path_to_tmp_file() -> str:
     """Get path to empty temporary file."""
